package chart;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;
import java.util.*;
import java.sql.SQLException;
import com.aspose.cells.*;
import com.aspose.cells.Chart;

public class AreaChartServlet
    extends HttpServlet {
  private static final String TEMPLATE_FILE_PATH_PART = "/WEB-INF/Designer/Chart/AreaTemplate.xls";

  public void doGet(HttpServletRequest request, HttpServletResponse response)
     throws IOException, ServletException
  {
    OutputStream out = response.getOutputStream();
    try
    {
        ServletContext sc = getServletContext();
        String template_file_path = sc.getRealPath(TEMPLATE_FILE_PATH_PART);

        String command = request.getParameter("CheckBoxShow3D");
        setResponseHeader(response, "AreaChart.xls");
        CreateAreaChart(out, template_file_path, command);
     }
    catch (Exception ex)
    {
        ex.printStackTrace();

        // say sorry
        response.setContentType("text/html");
        PrintWriter writer = new PrintWriter(out);

        writer.println("<html>");
        writer.println("<head>");
        writer.println("<title>sorry</title>");
        writer.println("</head>");
        writer.println("<body>");
        writer.println("<h1>Sorry, the demo programme failed for some reason.</h1>");
        ex.printStackTrace(writer);
        writer.println("</body>");
        writer.println("</html>");
        writer.close();
    }
  }

  public void doPost(HttpServletRequest request, HttpServletResponse response)
         throws IOException, ServletException
   {
      doGet(request, response);
   }

  private void setResponseHeader(HttpServletResponse response, String resultXLS)
  {
     response.setContentType("application/vnd.ms-excel");
     response.addHeader("content-disposition", "inline;  filename=" + resultXLS);
  }

  private void CreateAreaChart(OutputStream out,String template_file_path,String Parameter) throws IOException
  {
     Workbook workbook = new Workbook();

     workbook.open(template_file_path);
     CreateStaticReport(workbook, Parameter);

     workbook.save(out);
  }

  private void CreateStaticReport(Workbook workbook, String Parameter)
  {
     Worksheets worksheets = workbook.getWorksheets();
     Worksheet worksheet = worksheets.getSheet(0);
     //Set the name of worksheet
     worksheet.setName("Area");

     //Create chart
     Charts charts = worksheet.getCharts();
     int chartIndex = 0;
    if (Parameter != null)
      chartIndex = charts.add(ChartType.AREA_3D, 5, 1, 29, 10);
    else
       chartIndex = charts.add(ChartType.AREA, 5, 1, 29, 10);
     Chart chart = charts.getChart(chartIndex);

     //Set properties of nseries
     NSeries nSeries = chart.getNSeries();
     nSeries.add("B4:F4", false);
     nSeries.add("B3:F3", false);
     nSeries.add("B2:F2", false);
     nSeries.setCategoryData("B1:F1");

     Cells cells = worksheet.getCells();
     String temp = "";
     for (int i = 0; i < chart.getNSeries().size(); i ++)
     {
       temp = cells.getCell(i + 1, 0).getStringValue();
       nSeries.get(i).setName(temp);
       nSeries.get(i).setColorVaried(true);
     }

     //Set properties of Legend
     chart.getLegend().setPosition(LegendPositionType.TOP);

     //Set properties of chart title
     Title title = chart.getTitle();
     title.setText("Sales By Region");
     Font font1 = new Font();
     font1.setColor(Color.BLACK);
     font1.setBold(true);
     font1.setSize(12);
     title.setFont(font1);

     //Set properties of categoryaxis title
     CategoryAxis categoryAxis = chart.getCategoryAxis();
     categoryAxis.getTitle().setText("Year(2002-2006)");
     Font font2 = new Font();
     font2.setColor(Color.BLACK);
     font2.setBold(true);
     font2.setSize(10);
     categoryAxis.getTitle().setFont(font2);
     categoryAxis.setBetweenCategories(false);
  }
}
