package chart;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletResponse;
import java.io.OutputStream;
import com.aspose.cells.Style;
import com.aspose.cells.*;
import com.aspose.cells.Chart;
import javax.servlet.ServletContext;

public class BarofPieServlet extends HttpServlet {

  private static final String TEMPLATE_FILE_PATH_PART = "/WEB-INF/Designer/Chart/PieTemplate.xls";

  public void doGet(HttpServletRequest request, HttpServletResponse response)
 throws IOException, ServletException
{
OutputStream out = response.getOutputStream();
try
{
    ServletContext sc = getServletContext();
    String template_file_path = sc.getRealPath(TEMPLATE_FILE_PATH_PART);

    setResponseHeader(response, "BarofPie.xls");
    CreatePieChart(out, template_file_path);
 }
catch (Exception ex)
{
    ex.printStackTrace();

    // say sorry
    response.setContentType("text/html");
    PrintWriter writer = new PrintWriter(out);

    writer.println("<html>");
    writer.println("<head>");
    writer.println("<title>sorry</title>");
    writer.println("</head>");
    writer.println("<body>");
    writer.println("<h1>Sorry, the demo programme failed for some reason.</h1>");
    ex.printStackTrace(writer);
    writer.println("</body>");
    writer.println("</html>");
    writer.close();
}
}

public void doPost(HttpServletRequest request, HttpServletResponse response)
     throws IOException, ServletException
{
  doGet(request, response);
}

private void setResponseHeader(HttpServletResponse response, String resultXLS)
{
 response.setContentType("application/vnd.ms-excel");
 response.addHeader("content-disposition", "inline;  filename=" + resultXLS);
}

private void CreatePieChart(OutputStream out,String template_file_path) throws IOException
{
Workbook workbook = new Workbook();

 Style style = workbook.getDefaultStyle();
 Font font = new Font();
 font.setName("Tahoma");
 style.setFont(font);

 workbook.open(template_file_path);
 CreateStaticReport(workbook);

 workbook.save(out);
}

  private void CreateStaticReport(Workbook workbook)
  {
    Worksheets worksheets = workbook.getWorksheets();
    Worksheet worksheet = worksheets.getSheet(0);
    //Set the name of worksheet
    worksheet.setName("BarofPie");

    //Create chart
    Charts charts = worksheet.getCharts();
    int chartIndex =  charts.add(ChartType.PIE_BAR, 1, 3, 25, 13);
    Chart chart = charts.getChart(chartIndex);

    //Set properties of nseries
    NSeries nSeries = chart.getNSeries();
    nSeries.add("B2:B8", true);
    nSeries.setCategoryData("A2:A8");
    for (int i = 0; i < nSeries.size(); i ++)
    {
      nSeries.get(i).setColorVaried(true);
      nSeries.get(i).getDataLabels().setValueShown(true);
      nSeries.get(i).getDataLabels().setLabelPosition(LabelPositionType.OUTSIDE_END);
    }

    //Set properties of chart title
    Title title = chart.getTitle();
    title.setText("Sales By Region");
    Font font = new Font();
    font.setColor(Color.BLACK);
    font.setBold(true);
    font.setSize(12);
    title.setFont(font);
  }
}
