package chart;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletResponse;
import java.io.OutputStream;
import com.aspose.cells.Style;
import com.aspose.cells.*;
import com.aspose.cells.Chart;
import javax.servlet.ServletContext;

public class Column3DServlet extends HttpServlet {

  private static final String TEMPLATE_FILE_PATH_PART = "/WEB-INF/Designer/Chart/Template.xls";

  public void doGet(HttpServletRequest request, HttpServletResponse response)
     throws IOException, ServletException
  {
    OutputStream out = response.getOutputStream();
    try
    {
        ServletContext sc = getServletContext();
        String template_file_path = sc.getRealPath(TEMPLATE_FILE_PATH_PART);

        String columnType = request.getParameter("ColumnType");
        int wallsColor = Integer.parseInt(request.getParameter("WallsColor"));
        int floorColor = Integer.parseInt(request.getParameter("FloorColor"));
        int rotation = Integer.parseInt(request.getParameter("Rotation"));
        int elevation = Integer.parseInt(request.getParameter("Elevation"));
        int depthPercent = Integer.parseInt(request.getParameter("DepthPercent"));

        setResponseHeader(response, "Column3D.xls");
        CreateColumnChart(out, template_file_path, columnType, wallsColor,
                          floorColor, rotation, elevation, depthPercent);
     }
    catch (Exception ex)
    {
        ex.printStackTrace();

        // say sorry
        response.setContentType("text/html");
        PrintWriter writer = new PrintWriter(out);

        writer.println("<html>");
        writer.println("<head>");
        writer.println("<title>sorry</title>");
        writer.println("</head>");
        writer.println("<body>");
        writer.println("<h1>Sorry, the demo programme failed for some reason.</h1>");
        ex.printStackTrace(writer);
        writer.println("</body>");
        writer.println("</html>");
        writer.close();
    }
  }

  public void doPost(HttpServletRequest request, HttpServletResponse response)
         throws IOException, ServletException
   {
      doGet(request, response);
   }

  private void setResponseHeader(HttpServletResponse response, String resultXLS)
  {
     response.setContentType("application/vnd.ms-excel");
     response.addHeader("content-disposition", "inline;  filename=" + resultXLS);
  }

  private void CreateColumnChart(OutputStream out, String template_file_path, String columnType, int wallsColor,
     int floorColor, int rotation, int elevation, int depthPercent) throws IOException
 {
    Workbook workbook = new Workbook();

    workbook.open(template_file_path);
    CreateStaticReport(workbook, columnType, wallsColor, floorColor,
                       rotation, elevation, depthPercent);

    workbook.save(out);
 }

 private void CreateStaticReport(Workbook workbook, String columnType,int wallsColor,
     int floorColor, int rotation, int elevation, int depthPercent)
 {
   Worksheets worksheets = workbook.getWorksheets();
   Worksheet worksheet = worksheets.getSheet(0);
   //Set the name of the worksheet
   worksheet.setName("3D Column");

   //Create chart
   Charts charts = worksheet.getCharts();
   int chartIndex = 0;

   if (columnType.equals("Column3D"))
     chartIndex = charts.add(ChartType.COLUMN_3D, 5, 1, 29, 10);
   if (columnType.equals("Column3DClustered"))
     chartIndex = charts.add(ChartType.COLUMN_3D_CLUSTERED, 5 , 1, 29, 10);
   if (columnType.equals("Column3DStacked"))
     chartIndex = charts.add(ChartType.COLUMN_3D_STACKED, 5, 1, 29, 10);

   Chart chart = charts.getChart(chartIndex);

   //Set properties of chart
   NSeries nSeries = chart.getNSeries();
   nSeries.add("B2:B4", true);
   nSeries.setCategoryData("A2:A4");

   Cells cells = worksheet.getCells();
   String temp = "";
   for (int i = 0; i < nSeries.size(); i++)
   {
     temp = cells.getCell(i + 1, 0).getStringValue();
     nSeries.get(i).setName(temp);
     nSeries.get(i).setColorVaried(true);
   }

   //Set properies to title
   Title title = chart.getTitle();
   title.setText("Marketing Costs by Region");
   Font font1 = new Font();
   font1.setBold(true);
   font1.setColor(Color.BLACK);
   font1.setSize(12);
   title.setFont(font1);

   //Set properties of categoryaxis title
   CategoryAxis categoryAxis = chart.getCategoryAxis();
   categoryAxis.getTitle().setText("Region");
   Font font2 = new Font();
   font2.setBold(true);
   font2.setColor(Color.BLACK);
   font2.setSize(10);
   categoryAxis.getTitle().setFont(font2);

   //Set properties of valueaxis title
   ValueAxis valueAxis = chart.getValueAxis();
   valueAxis.getTitle().setText("In Thousands");
   valueAxis.getTitle().setFont(font2);
   valueAxis.getTitle().setRotation(90);

   //Set the legend position type
   chart.getLegend().setPosition(LegendPositionType.TOP);
   chart.getPlotArea().getBorder().setVisible(false);

   //Set properties of chart
   Walls walls = chart.getWalls();
   switch (wallsColor)
   {
     case 0:
       walls.getArea().setForegroundColor(Color.WHITE);
       break;
      case 1:
        walls.getArea().setForegroundColor(Color.RED);
        break;
      case 2:
        walls.getArea().setForegroundColor(Color.BLUE);
        break;
      case 3:
        walls.getArea().setForegroundColor(Color.SILVER);
        break;
      case 4:
        walls.getArea().setForegroundColor(Color.GRAY);
        break;
   }

   Floor floor = chart.getFloor();
   switch (floorColor)
   {
     case 0:
        floor.getArea().setForegroundColor(Color.WHITE);
        break;
     case 1:
        floor.getArea().setForegroundColor(Color.RED);
        break;
     case 2:
        floor.getArea().setForegroundColor(Color.BLUE);
        break;
     case 3:
        floor.getArea().setForegroundColor(Color.SILVER);
        break;
     case 4:
        floor.getArea().setForegroundColor(Color.GRAY);
        break;
   }

   chart.setRotation(rotation);
   chart.setElevation(elevation);
   chart.setDepthPercent(depthPercent);
 }
}
