package chart;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletResponse;
import java.io.OutputStream;
import com.aspose.cells.Style;
import com.aspose.cells.*;
import com.aspose.cells.Chart;
import javax.servlet.ServletContext;

public class DoughnutServlet extends HttpServlet {
  private static final String TEMPLATE_FILE_PATH_PART = "/WEB-INF/Designer/Chart/DoughnutTemplate.xls";

  public void doGet(HttpServletRequest request, HttpServletResponse response)
 throws IOException, ServletException
{
OutputStream out = response.getOutputStream();
try
{
    ServletContext sc = getServletContext();
    String template_file_path = sc.getRealPath(TEMPLATE_FILE_PATH_PART);

    setResponseHeader(response, "Doughnut.xls");
    CreateDoughnutChart(out, template_file_path);
 }
catch (Exception ex)
{
    ex.printStackTrace();

    // say sorry
    response.setContentType("text/html");
    PrintWriter writer = new PrintWriter(out);

    writer.println("<html>");
    writer.println("<head>");
    writer.println("<title>sorry</title>");
    writer.println("</head>");
    writer.println("<body>");
    writer.println("<h1>Sorry, the demo programme failed for some reason.</h1>");
    ex.printStackTrace(writer);
    writer.println("</body>");
    writer.println("</html>");
    writer.close();
}
}

public void doPost(HttpServletRequest request, HttpServletResponse response)
     throws IOException, ServletException
{
  doGet(request, response);
}

private void setResponseHeader(HttpServletResponse response, String resultXLS)
{
 response.setContentType("application/vnd.ms-excel");
 response.addHeader("content-disposition", "inline;  filename=" + resultXLS);
}

private void CreateDoughnutChart(OutputStream out, String template_file_path) throws IOException
{
Workbook workbook = new Workbook();

 workbook.open(template_file_path);
 CreateStaticReport(workbook);

 workbook.save(out);
}

  private void CreateStaticReport(Workbook workbook)
  {
    Worksheets worksheets = workbook.getWorksheets();
    Worksheet worksheet = worksheets.getSheet(0);
    //Set the name of worksheet
    worksheet.setName("Doughnut");

    //Create chart
    Charts charts = worksheet.getCharts();
    int chartIndex = charts.add(ChartType.DOUGHNUT, 3, 1, 27, 10);
    Chart chart = charts.getChart(chartIndex);

    //Set the properties of nseries
    NSeries nSeries = chart.getNSeries();
    nSeries.add("B2:C3", true);
    nSeries.setCategoryData("B1:C1");
    for (int i = 0; i < nSeries.size(); i ++)
    {
       nSeries.get(i).getDataLabels().setValueShown(true);
       nSeries.get(i).setColorVaried(true);
    }

    //Set the properties of chart title
    Title title = chart.getTitle();
    title.setText("Fruit Sales by Region For Years");
    Font font1 = new Font();
    font1.setBold(true);
    font1.setColor(Color.BLACK);
    font1.setSize(12);
    title.setFont(font1);

    //Set the properties of categoryaxis title
    CategoryAxis categoryAxis = chart.getCategoryAxis();
    categoryAxis.getTitle().setText("Region");
    Font font2 = new Font();
    font2.setBold(true);
    font2.setColor(Color.BLACK);
    font2.setSize(10);
    categoryAxis.getTitle().setFont(font2);

    //Set the properties of valueaxis title
    ValueAxis valueAxis = chart.getValueAxis();
    valueAxis.getTitle().setText("In Thousand");
    Font font3 = new Font();
    font3.setBold(true);
    font3.setColor(Color.BLACK);
    font3.setSize(10);
    valueAxis.getTitle().setFont(font3);

    //Set the properties of legend
    Legend legend = chart.getLegend();
    legend.setPosition(LegendPositionType.TOP);
  }
}
