package chart;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletResponse;
import java.io.OutputStream;
import com.aspose.cells.Style;
import com.aspose.cells.*;
import com.aspose.cells.Chart;
import javax.servlet.ServletContext;

public class LineServlet  extends HttpServlet{

  private static final String TEMPLATE_FILE_PATH_PART = "/WEB-INF/Designer/Chart/AreaTemplate.xls";

  public void doGet(HttpServletRequest request, HttpServletResponse response)
    throws IOException, ServletException
 {
   OutputStream out = response.getOutputStream();
   try
   {
       ServletContext sc = getServletContext();
       String template_file_path = sc.getRealPath(TEMPLATE_FILE_PATH_PART);

       int chartType = Integer.parseInt(request.getParameter("ChartTypeList"));
       int nseriesMarkerStyle = Integer.parseInt(request.getParameter("NSeriesMarkerStyle"));
       int nMarkBackColor =Integer.parseInt(request.getParameter("NMarkBackColor"));
       int nMarkForeColor = Integer.parseInt(request.getParameter("NMarkForeColor"));
       int nseriesMarkSize = Integer.parseInt(request.getParameter("NSeriesMarkSize"));
       setResponseHeader(response, "Line.xls");
       CreateLineChart(out, template_file_path, chartType, nseriesMarkerStyle,
                       nMarkBackColor, nMarkForeColor, nseriesMarkSize);
    }
   catch (Exception ex)
   {
       ex.printStackTrace();

       // say sorry
       response.setContentType("text/html");
       PrintWriter writer = new PrintWriter(out);

       writer.println("<html>");
       writer.println("<head>");
       writer.println("<title>sorry</title>");
       writer.println("</head>");
       writer.println("<body>");
       writer.println("<h1>Sorry, the demo programme failed for some reason.</h1>");
       ex.printStackTrace(writer);
       writer.println("</body>");
       writer.println("</html>");
       writer.close();
   }
 }

 public void doPost(HttpServletRequest request, HttpServletResponse response)
        throws IOException, ServletException
  {
     doGet(request, response);
  }

 private void setResponseHeader(HttpServletResponse response, String resultXLS)
 {
    response.setContentType("application/vnd.ms-excel");
    response.addHeader("content-disposition", "inline;  filename=" + resultXLS);
 }

 private void CreateLineChart(OutputStream out, String template_file_path, int chartType, int nseriesMarkerStyle,
                              int nMarkBackColor, int nMarkForeColor, int nseriesMarkSize) throws IOException
 {
   Workbook workbook = new Workbook();

    workbook.open(template_file_path);

    CreateStaticReport(workbook, chartType, nseriesMarkerStyle, nMarkBackColor,
                       nMarkForeColor, nseriesMarkSize);

    workbook.save(out);
 }

 private void CreateStaticReport(Workbook workbook, int chartType, int nseriesMarkerStyle,
     int nMarkBackColor, int nMarkForeColor, int nseriesMarkSize)
  {
    Worksheets worksheets = workbook.getWorksheets();
    Worksheet worksheet = worksheets.getSheet(0);
    //Set the name of worksheet
    worksheet.setName("Line");

    //Create chart
    Charts charts = worksheet.getCharts();
    int chartIndex = 0;
    switch (chartType)
    {
      case 0:
        chartIndex = charts.add(ChartType.LINE, 5, 1, 29, 10);
         break;
       case 1:
         chartIndex = charts.add(ChartType.LINE_WITH_DATA_MARKERS, 5, 1, 29, 10);
         break;
    }
    Chart chart = charts.getChart(chartIndex);

    //Set Properties of nseries
    NSeries nSeries = chart.getNSeries();
    nSeries.add("B2:F4", false);
    nSeries.setCategoryData("B1:F1");

    Cells cells = worksheet.getCells();
    String temp = "";
    for (int i = 0; i < nSeries.size(); i ++)
    {
      temp = cells.getCell(i + 1, 0).getStringValue();
      nSeries.get(i).setName(temp);

      switch (nseriesMarkerStyle)
      {
        case 0:
         nSeries.get(i).setMarkerStyle(ChartMarkerType.CIRCLE);
         break;
        case 1:
          nSeries.get(i).setMarkerStyle(ChartMarkerType.SQUARE_STAR);
          break;
        case 2:
          nSeries.get(i).setMarkerStyle(ChartMarkerType.SQUARE_X);
          break;
      }
      switch (nMarkBackColor)
      {
          case 0:
            nSeries.get(i).setMarkerBackgroundColor(Color.RED);
            break;
          case 1:
            nSeries.get(i).setMarkerBackgroundColor(Color.TEAL);
            break;
          case 2:
            nSeries.get(i).setMarkerBackgroundColor(Color.GRAY);
            break;
      }
      switch (nMarkForeColor)
      {
        case 0:
          nSeries.get(i).setMarkerForegroundColor(Color.RED);
          break;
        case 1:
          nSeries.get(i).setMarkerForegroundColor(Color.LIME);
          break;
        case 2:
          nSeries.get(i).setMarkerForegroundColor(Color.GRAY);
          break;
      }
    }

    //Set Properties of chart title
    Title title = chart.getTitle();
    title.setText("Sales By Region For Years");
    Font font1 = new Font();
    font1.setBold(true);
    font1.setColor(Color.BLACK);
    font1.setSize(12);
    title.setFont(font1);

    //Set Properties of categoryaxis title
    CategoryAxis categoryAxis = chart.getCategoryAxis();
    categoryAxis.getTitle().setText("Year(2002-2006)");
    Font font2 = new Font();
    font2.setBold(true);
    font2.setColor(Color.BLACK);
    font2.setSize(10);
    categoryAxis.getTitle().setFont(font2);

    //Set the legend position type
    Legend legend = chart.getLegend();
    legend.setPosition(LegendPositionType.TOP);
  }
}
